@@ -32,7 +32,7 @@ def get_schema(client, properties_flag, stream_name):
     if stream_name == 'engage':
         properties = client.request(
             method='GET',
-            url='https://mixpanel.com/api/2.0',
+            url='https://{}/api/2.0'.format(client.__api_domain),
             path='engage/properties',
             params={'limit': 2000},
             endpoint='engage_properties')
@@ -91,7 +91,7 @@ def get_schema(client, properties_flag, stream_name):
         #  https://developer.mixpanel.com/docs/data-export-api#section-hr-span-style-font-family-courier-top-span
         results = client.request(
             method='GET',
-            url='https://mixpanel.com/api/2.0',
+            url='https://{}/api/2.0'.format(client.__api_domain),
             path='events/properties/top',
             params={'limit': 2000},
             endpoint='event_properties')
@@ -130,10 +130,22 @@ def get_schemas(client, properties_flag):
         # https://github.com/singer-io/singer-python/blob/master/singer/metadata.py#L25-L44
         mdata = metadata.get_standard_metadata(
             schema=schema,
-            key_properties=stream_metadata.get('key_properties', None),
-            valid_replication_keys=stream_metadata.get('replication_keys', None),
-            replication_method=stream_metadata.get('replication_method', None)
+            key_properties=stream_metadata.key_properties,
+            valid_replication_keys=stream_metadata.replication_keys,
+            replication_method=stream_metadata.replication_method
         )
+
+        mdata = metadata.to_map(mdata)
+
+        if stream_metadata.replication_keys:
+                mdata = metadata.write(
+                    mdata,
+                    ('properties', stream_metadata.replication_keys[0]),
+                    'inclusion',
+                    'automatic')
+
+        mdata = metadata.to_list(mdata)
+
         field_metadata[stream_name] = mdata
 
     return schemas, field_metadata
