@@ -4,6 +4,6 @@ from tap_mixpanel.client import MixpanelClient
 
 @pytest.fixture
 def mixpanel_client():
-    mixpanel_client = MixpanelClient('API_SECRET')
+    mixpanel_client = MixpanelClient('API_SECRET', api_domain="mixpanel.com")
     mixpanel_client._MixpanelClient__verified = True
     return mixpanel_client
